% ode04A.m
%
% Numerically integrate a 1D ODE (gravitational acceleration with turbulent
% air drag) using the Runge-Kutta 45 solver. 
%
% Equation of Motion:
%    ma = - mg - C_d v |v|
%     m = free parameter 
%   C_d = drag force coefficient
%
% This code calls the user-definied function air_drag_1D_derivs.m, which must
% be in the same folder as this code
%

close all
clear
clc

%%%%%%%%%%   Initialize Parameters   %%%%%%%%%%

tBegin = 0;     % time begin
tEnd   = 10;    % time end

x0  = 5;        % initial position (x0,y0)
y0  = 0;     
vx0 = 0;        % initial velocity (vx0,vy0)
vy0 = 0;


%%%%%%%%%%%   define global variables used in derivative function
global m;       % mass (kg)
m = 1; 

global k;       % spring constant
k = 5;



%%%%%%%%%%  Use the Runge-Kutta 45 solver to solve the ODE  %%%%%%%%%%

[t,w] = ode45(@C01_derivs, [tBegin tEnd], [x0 y0 vx0 vy0]);   

x  = w(:,1);     % extract positions from w matrix
y  = w(:,2); 
vx = w(:,3);     % extract velocity components from w matrix
vy = w(:,4); 

%%%%%%%%%%  Plot Results   %%%%%%%%%%

plot(t,x,'b-');
hold on
plot(t,y,'b--');
legend('x','y')
ylabel('x (m)');
xlabel('t (s)');



