    % C01_derivs - Function returns the derivatives for a mass attached to
    %              a spring moving in 2D space
    %
    % Force on object = spring force
    %              Fx = -(k/m)*x 
    %              Fy = -(k/m)*y 
    % 
    % Required global variables:
    %   m   = mass of object
    %   k   = spring constant

    function derivs = C01_derivs(t, w)
    
        global k;         % spring constant
        global m;         % mass of particle 
             
        x  = w(1);        % (x,y) coordinates of particle 
        y  = w(2);        %
        
        vx = w(3);        % velocity components of particle 
        vy = w(4);        %    
        
        dxdt = vx;        % returned velocity components
        dydt = vy;        % 

        dvxdt = -k/m*x;   % returned acceleration components
        dvydt = -k/m*y;   %
        
        derivs = [dxdt; dydt; dvxdt; dvydt];  % return the derivatives
        
    end

